#########################
InputProfilePhotoAnimated
#########################


.. automodule:: litegram.types.input_profile_photo_animated
    :members:
    :member-order: bysource
    :undoc-members: True
    :exclude-members: model_config,model_fields
